WWTLabApplication
=================

.. currentmodule:: pywwt.jupyter

.. autoclass:: WWTLabApplication
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~WWTLabApplication.layer_controls

   .. rubric:: Attributes Documentation

   .. autoattribute:: layer_controls
